@@ -4,6 +4,7 @@
 #
 # Copyright (c) 2005-2009 Edward Hervey <bilboed@bilboed.com>
 # Copyright (c) 2008-2009 Alessandro Decina <alessandro.d@gmail.com>
+# Copyright (c) 2010      Google <aleb@google.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -40,7 +41,7 @@ import pitivi.instance as instance
 
 from pitivi.check import initial_checks
 from pitivi.device import get_probe
-from pitivi.effects import Magician
+from pitivi.effects import EffectsHandler
 from pitivi.configure import APPNAME
 from pitivi.settings import GlobalSettings
 from pitivi.threads import ThreadMaster
@@ -53,7 +54,9 @@ from pitivi.projectmanager import ProjectManager, ProjectLogObserver
 from pitivi.undo import UndoableActionLog, DebugActionLogObserver
 from pitivi.timeline.timeline_undo import TimelineLogObserver
 from pitivi.sourcelist_undo import SourceListLogObserver
-from pitivi.undo import UndoableAction
+from pitivi.ui.viewer import PitiviViewer
+from pitivi.actioner import Renderer, Previewer
+from pitivi.ui.startupwizard import StartUpWizard
 
 # FIXME : Speedup loading time
 # Currently we load everything in one go
@@ -62,8 +65,6 @@ from pitivi.undo import UndoableAction
 # AND THEN load up the required parts.
 # This will result in a much better end-user experience
 
-# FIXME : maybe we should have subclasses for UI and CLI
-
 class Pitivi(Loggable, Signallable):
     """
     Pitivi's main application class.
@@ -92,17 +93,15 @@ class Pitivi(Loggable, Signallable):
     """
 
     __signals__ = {
-        "new-project" : ["project"],
-
-        "new-project-loading" : ["uri"],
-        "new-project-created" : ["project"],
-        "new-project-loaded" : ["project"],
-        "new-project-failed" : ["uri", "exception"],
-        "closing-project" : ["project"],
-        "project-closed" : ["project"],
-        "missing-uri" : ["formatter", "uri"],
-        "shutdown" : None
-        }
+        "new-project": ["project"],
+        "new-project-loading": ["uri"],
+        "new-project-created": ["project"],
+        "new-project-loaded": ["project"],
+        "new-project-failed": ["uri", "exception"],
+        "closing-project": ["project"],
+        "project-closed": ["project"],
+        "missing-uri": ["formatter", "uri"],
+        "shutdown": None}
 
     def __init__(self):
         """
@@ -134,10 +133,10 @@ class Pitivi(Loggable, Signallable):
         self.plugin_manager = PluginManager(
             self.settings.get_local_plugin_path(),
             self.settings.get_plugin_settings_path())
-        self.effects = Magician()
+        self.effects = EffectsHandler()
         self.deviceprobe = get_probe()
 
-        self.projectManager = ProjectManager()
+        self.projectManager = ProjectManager(self.effects)
         self._connectToProjectManager(self.projectManager)
 
         self.action_log = UndoableActionLog()
@@ -147,8 +146,6 @@ class Pitivi(Loggable, Signallable):
         self.projectLogObserver = ProjectLogObserver(self.action_log)
         self.sourcelist_log_observer = SourceListLogObserver(self.action_log)
 
-    #{ Shutdown methods
-
     def shutdown(self):
         """
         Close PiTiVi.
@@ -159,7 +156,7 @@ class Pitivi(Loggable, Signallable):
         self.debug("shutting down")
         # we refuse to close if we're running a user interface and the user
         # doesn't want us to close the current project.
-        if self.projectManager.current and not self.projectManager.closeRunningProject():
+        if self.current and not self.projectManager.closeRunningProject():
             self.warning("Not closing since running project doesn't want to close")
             return False
         self.threads.stopAllThreads()
@@ -172,8 +169,6 @@ class Pitivi(Loggable, Signallable):
         self.emit("shutdown")
         return True
 
-    #}
-
     def _connectToProjectManager(self, projectManager):
         projectManager.connect("new-project-loading",
                 self._projectManagerNewProjectLoading)
@@ -195,12 +190,16 @@ class Pitivi(Loggable, Signallable):
         self.current = project
         self.emit("new-project-created", project)
 
+    def _newProjectLoaded(self, project):
+        pass
+
     def _projectManagerNewProjectLoaded(self, projectManager, project):
         self.current = project
         self.action_log.clean()
         self.timelineLogObserver.startObserving(project.timeline)
         self.projectLogObserver.startObserving(project)
         self.sourcelist_log_observer.startObserving(project.sources)
+        self._newProjectLoaded(project)
         self.emit("new-project-loaded", project)
 
     def _projectManagerNewProjectFailed(self, projectManager, uri, exception):
@@ -215,111 +214,126 @@ class Pitivi(Loggable, Signallable):
         self.current = None
         self.emit("project-closed", project)
 
+
 class InteractivePitivi(Pitivi):
-    usage = _("""
-      %prog [PROJECT_FILE]
-      %prog -i [-a] [MEDIA_FILE]...""")
+    """
+    Base class to launch interactive PiTiVi
+    """
 
-    description = _("""Starts the video editor, optionally loading PROJECT_FILE. If
-no project is given, %prog creates a new project.
-Alternatively, when -i is specified, arguments are treated as clips to be
-imported into the project. If -a is specified, these clips will also be added to
-the end of the project timeline.""")
-
-    import_help = _("""Import each MEDIA_FILE into the project.""")
-
-    add_help = _("""Add each MEDIA_FILE to timeline after importing.""")
-    debug_help = _("""Run pitivi in the Python Debugger""")
-
-    no_ui_help = _("""Run pitivi with no gui""")
-
-    def __init__(self):
+    def __init__(self, debug=False):
         Pitivi.__init__(self)
         self.mainloop = gobject.MainLoop()
+        self.actioner = None
+        self.gui = None
 
-    def run(self, argv):
-        # check for dependencies
-        if not self._checkDependencies():
-            return
-
-        # parse cmdline options
-        parser = self._createOptionParser()
-        options, args = parser.parse_args(argv)
-
-        if options.debug:
-            sys.excepthook = self._excepthook
-
-        # validate options
-        if options.no_ui:
-            self.gui = None
-        else:
-            # create the ui
-            self.gui = PitiviMainWindow(self)
-            self.gui.show()
-
-        if not options.import_sources and options.add_to_timeline:
-            parser.error("-a requires -i")
-            return
-
-        if not options.import_sources and len(args) > 1:
-            parser.error("invalid arguments")
-            return
-
-        if not options.import_sources and args:
-            # load a project file
-            project = "file://%s" % os.path.abspath(args[0])
-            self.projectManager.loadProject(project)
-        else:
-            # load the passed filenames, optionally adding them to the timeline
-            # (useful during development)
-            self.projectManager.newBlankProject()
-            uris = ["file://" + urllib.quote(os.path.abspath(path)) for path in args]
-            self.current.sources.connect("source-added",
-                    self._sourceAddedCb, uris, options.add_to_timeline)
-            self.current.sources.connect("discovery-error",
-                    self._discoveryErrorCb, uris)
-            self.current.sources.addUris(uris)
-
-        # run the mainloop
-        self.mainloop.run()
-
-    def shutdown(self):
-        if Pitivi.shutdown(self):
-            if self.gui:
-                self.gui.destroy()
-            self.mainloop.quit()
-            return True
-
-        return False
-
-    def _createOptionParser(self):
-        parser = OptionParser(self.usage, description=self.description)
-        parser.add_option("-i", "--import", help=self.import_help,
-                dest="import_sources", action="store_true", default=False)
-        parser.add_option("-a", "--add-to-timeline", help=self.add_help,
-                action="store_true", default=False)
-        parser.add_option("-d", "--debug", help=self.debug_help,
-                action="store_true", default=False)
-        parser.add_option("-n", "--no-ui", help=self.no_ui_help,
-                action="store_true", default=False)
-
-        return parser
-
-
-    def _checkDependencies(self):
+        # Check the dependencies.
         missing_deps = initial_checks()
         if missing_deps:
             message, detail = missing_deps
-            dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR,
-                                       buttons=gtk.BUTTONS_OK)
-            dialog.set_icon_name("pitivi")
-            dialog.set_markup("<b>"+message+"</b>")
-            dialog.format_secondary_text(detail)
-            dialog.run()
+            self._showStartupError(message, detail)
+            sys.exit(2)
 
-            return False
+        if debug:
+            sys.excepthook = self._excepthook
 
-        return True
+    def _showStartupError(self, message, detail):
+        self.error("%s %s" % (message, detail))
+
+    def _excepthook(self, exc_type, value, tback):
+        import traceback
+        import pdb
+        traceback.print_tb(tback)
+        pdb.post_mortem(tback)
+
+    def _setActioner(self, actioner):
+        self.actioner = actioner
+        if self.actioner:
+            self.actioner.connect("eos", self._eosCb)
+            # On error, all we need to do is shutdown which
+            # is the same as we do for EOS
+            self.actioner.connect("error", self._eosCb)
+            # Configure the actioner and start acting!
+            self.actioner.startAction()
+
+    def _eosCb(self, unused_obj):
+        raise NotImplementedError()
+
+    def _loadProject(self, project_filename):
+        project = "file://%s" % os.path.abspath(project_filename)
+        self.projectManager.loadProject(project)
+
+    def run(self):
+        """Runs the main loop."""
+        self.mainloop.run()
+
+
+class GuiPitivi(InteractivePitivi):
+    """
+    Base class to launch PiTiVi with UI
+    """
+
+    def __init__(self, debug=False):
+        InteractivePitivi.__init__(self, debug)
+        self._showGui()
+
+    def _showStartupError(self, message, detail):
+        dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR,
+                                   buttons=gtk.BUTTONS_OK)
+        dialog.set_icon_name("pitivi")
+        dialog.set_markup("<b>"+message+"</b>")
+        dialog.format_secondary_text(detail)
+        dialog.run()
+
+    def _eosCb(self, unused_obj):
+        self.shutdown()
+
+    def _createGui(self):
+        """Returns a gtk.Widget which represents the UI."""
+        raise NotImplementedError()
+
+    def _showGui(self):
+        """Creates and shows the UI."""
+        self.gui = self._createGui()
+        self.gui.show()
+
+    def shutdown(self):
+        if Pitivi.shutdown(self):
+            self.gui.destroy()
+            self.mainloop.quit()
+            return True
+        return False
+
+
+class FullGuiPitivi(GuiPitivi):
+    """
+    Creates an instance of PiTiVi with the UI
+
+    This is called when we start the UI with a project passed as a parameter,
+    but not when we start with the welcome dialog.
+    """
+
+    def _createGui(self):
+        return PitiviMainWindow(self)
+
+
+class ProjectCreatorGuiPitivi(FullGuiPitivi):
+    """
+    Creates an instance of PiTiVi with the UI and loading a list
+    of clips, adding them to the timeline or not
+    """
+
+    def __init__(self, media_filenames, add_to_timeline=False, debug=False):
+        FullGuiPitivi.__init__(self, debug)
+        # load the passed filenames, optionally adding them to the timeline
+        # (useful during development)
+        self.projectManager.newBlankProject()
+        uris = ["file://" + urllib.quote(os.path.abspath(media_filename))
+                for media_filename in media_filenames]
+        self.current.sources.connect("source-added",
+                self._sourceAddedCb, uris, add_to_timeline)
+        self.current.sources.connect("discovery-error",
+                self._discoveryErrorCb, uris)
+        self.current.sources.addUris(uris)
 
     def _sourceAddedCb(self, sourcelist, factory,
             startup_uris, add_to_timeline):
@@ -347,12 +361,173 @@ the end of the project timeline.""")
 
         return True
 
-    def _excepthook(self, exc_type, value, tback):
-        import traceback
-        import pdb
-        traceback.print_tb(tback)
-        pdb.post_mortem(tback)
+
+class ProjectLoaderGuiPitivi(FullGuiPitivi):
+    """
+    Creates an instance of the UI and loads @project_filename
+    """
+
+    def __init__(self, project_filename, debug=False):
+        FullGuiPitivi.__init__(self, debug)
+        self._loadProject(project_filename)
+
+
+class StartupWizardGuiPitivi(FullGuiPitivi):
+    """
+    Creates an instance of the PiTiVi UI with the welcome dialog
+
+    This is not called when a project is passed as a parameter.
+    """
+
+    def __init__(self, debug=False):
+        FullGuiPitivi.__init__(self, debug)
+        self.projectManager.newBlankProject()
+
+    def _createGui(self):
+        self.projectManager.connect("new-project-loading", self._hideWizardCb)
+        self.projectManager.connect("new-project-failed", self._showWizardCb)
+        self.wizard = StartUpWizard(self)
+        self.wizard.hide()
+        return FullGuiPitivi._createGui(self)
+
+    def _showGui(self):
+        FullGuiPitivi._showGui(self)
+        self.wizard.show()
+
+    def _hideWizardCb(self, unused_projectManager, uri):
+        if uri is not None:
+            self.wizard.hide()
+
+    def _showWizardCb(self, unused_projectManager, unused_uri, unused_exception):
+        self.wizard.show()
+
+
+class PreviewGuiPitivi(GuiPitivi):
+    """
+    Creates an instance of PiTiVi which plays the @project_filename
+    in a basic UI.
+    """
+
+    def __init__(self, project_filename, debug=False):
+        GuiPitivi.__init__(self, debug)
+
+        self._loadProject(project_filename)
+
+    def _createGui(self):
+        self.viewer = PitiviViewer(self)
+        window = gtk.Window()
+        window.connect("delete-event", self._deleteCb)
+        window.add(self.viewer)
+        return window
+
+    def _deleteCb(self, unused_widget, unused_data):
+        self.shutdown()
+
+    def _eosCb(self, unused_obj):
+        self.viewer.seek(0)
+
+    def _newProjectLoaded(self, project):
+        # create previewer and set ui
+        previewer = Previewer(self.current, pipeline=None, ui=self.viewer)
+        self._setActioner(previewer)
+        # hack to make the gtk.HScale seek slider UI behave properly
+        self.viewer._durationChangedCb(None, project.timeline.duration)
+
+
+class RenderingNoGuiPitivi(InteractivePitivi):
+    """
+    Creates an instance of PiTiVi with no UI which aims
+    at rendering the @project_filename project in @output_filename file
+    """
+
+    def __init__(self, project_filename, output_filename, debug=False):
+        InteractivePitivi.__init__(self, debug)
+        self.outfile = "file://%s" % os.path.abspath(output_filename)
+        self._loadProject(project_filename)
+
+    def _eosCb(self, unused_obj):
+        self.shutdown()
+
+    def _newProjectLoaded(self, project):
+        # create renderer and set output file
+        renderer = Renderer(self.current, outfile=self.outfile)
+        self._setActioner(renderer)
+
+    def shutdown(self):
+        if Pitivi.shutdown(self):
+            self.mainloop.quit()
+            return True
+        return False
+
+
+def _parse_options(argv):
+    parser = OptionParser(
+            usage=_("""
+    %prog [PROJECT_FILE]               # Start the video editor.
+    %prog -i [-a] [MEDIA_FILE1 ...]    # Start the editor and create a project.
+    %prog PROJECT_FILE -r OUTPUT_FILE  # Render a project.
+    %prog PROJECT_FILE -p              # Preview a project."""))
+
+    parser.add_option("-i", "--import", dest="import_sources",
+            action="store_true", default=False,
+            help=_("Import each MEDIA_FILE into a new project."))
+    parser.add_option("-a", "--add-to-timeline",
+            action="store_true", default=False,
+            help=_("Add each imported MEDIA_FILE to the timeline."))
+    parser.add_option("-d", "--debug",
+            action="store_true", default=False,
+            help=_("Run Pitivi in the Python Debugger."))
+    parser.add_option("-r", "--render", dest="render_output",
+            action="store", default=None,
+            help=_("Render the specified project to OUTPUT_FILE with no GUI."))
+    parser.add_option("-p", "--preview",
+            action="store_true", default=False,
+            help=_("Preview the specified project file without the full UI."))
+    options, args = parser.parse_args(argv[1:])
+
+    # Validate options.
+    if options.render_output and options.preview:
+        parser.error("-p and -r cannot be used simultaneously")
+
+    if options.import_sources and (options.render_output or options.preview):
+        parser.error("-r or -p and -i are incompatible")
+
+    if options.add_to_timeline and not options.import_sources:
+        parser.error("-a requires -i")
+
+    # Validate args.
+    if options.import_sources:
+        # When no MEDIA_FILE is specified, we just create a new project.
+        pass
+    elif options.render_output:
+        if len(args) != 1:
+            parser.error("-r requires exactly one PROJECT_FILE")
+    elif options.preview:
+        if len(args) != 1:
+            parser.error("-p requires exactly one PROJECT_FILE")
+    else:
+        if len(args) > 1:
+            parser.error("Cannot open more than one PROJECT_FILE")
+
+    return options, args
+
 
 def main(argv):
-    ptv = InteractivePitivi()
-    ptv.run(sys.argv[1:])
+    options, args = _parse_options(argv)
+    if options.import_sources:
+        ptv = ProjectCreatorGuiPitivi(media_filenames=args,
+                                      add_to_timeline=options.add_to_timeline,
+                                      debug=options.debug)
+    elif options.render_output:
+        ptv = RenderingNoGuiPitivi(project_filename=args[0],
+                                   output_filename=options.render_output,
+                                   debug=options.debug)
+    elif options.preview:
+        ptv = PreviewGuiPitivi(project_filename=args[0], debug=options.debug)
+    else:
+        if args:
+            ptv = ProjectLoaderGuiPitivi(project_filename=args[0],
+                                         debug=options.debug)
+        else:
+            ptv = StartupWizardGuiPitivi(debug=options.debug)
+    ptv.run()
