@@ -25,15 +25,17 @@ Enables identical use for installed and uninstalled versions.
 
 import os.path
 
-LIBDIR = '/usr/lib'
-PKGDATADIR = '/usr/share/pitivi'
-PIXMAPDIR = '/usr/share/pixmaps'
-pitivi_version = '0.13.4.2'
+LIBDIR = '/usr/local/lib'
+PKGDATADIR = '/usr/local/share/pitivi'
+PIXMAPDIR = '/usr/local/share/pixmaps'
+pitivi_version = '0.13.9.90'
 APPNAME = 'PiTiVi'
+APPURL = 'http://www.pitivi.org/'
+APPMANUALURL = 'http://www.pitivi.org/?go=documentation'
 PYGTK_REQ = '2.14.0'
 PYGST_REQ = '0.10.19'
 GST_REQ = '0.10.28'
-GNONLIN_REQ = '0.10.15'
+GNONLIN_REQ = '0.10.16'
 PYCAIRO_REQ = '1.0.0'
 
 def _get_root_dir():
@@ -50,6 +52,9 @@ def get_pixmap_dir():
     _dir = os.path.dirname(os.path.abspath(__file__))
     if _in_devel():
         root = _dir
+    elif os.getenv("PITIVI_TOP_LEVEL_DIR"):
+        top_level = os.getenv("PITIVI_TOP_LEVEL_DIR")
+        root = os.path.abspath(os.path.join(top_level, "pitivi"))
     else:
         root = PKGDATADIR
     return os.path.join(root, 'pixmaps')
