@@ -20,6 +20,7 @@
 # Boston, MA 02111-1307, USA.
 
 import gst
+import gobject
 
 from pitivi.signalinterface import Signallable
 from pitivi.utils import get_controllable_properties, getPreviousObject, \
@@ -123,7 +124,7 @@ class Interpolator(Signallable, Loggable):
       removing, and mutating discrete keyframe objects
 
     There are two special control points: the start and end points, which are
-    "fixed" to the start and end of the clip in the timeline. 
+    "fixed" to the start and end of the clip in the timeline.
 
     Timestamps given are assumed to be relative to the start of the clip. This
     seems to be the normal behavior when the element being controlled is
@@ -185,6 +186,10 @@ class Interpolator(Signallable, Loggable):
         that the new keyframe likes on the existing curve at that timestampi
 
         returns: the keyframe object"""
+        if time_or_keyframe is self.start or time_or_keyframe is self.end:
+            self.debug("We don't want to add the starting and end keyframes to"
+                       " our list of controlled keyframes")
+            return
 
         if isinstance(time_or_keyframe, Keyframe):
             keyframe = time_or_keyframe
@@ -218,6 +223,10 @@ class Interpolator(Signallable, Loggable):
         return keyframe
 
     def removeKeyframe(self, keyframe):
+        if keyframe not in self._keyframes:
+            self.debug("This keyframe doesn't belong to me")
+            return
+
         old_value = self._controller.get(self._property.name, keyframe.time)
         self._controller.unset(self._property.name, keyframe.time)
         if keyframe is not self.start and keyframe is not self.end:
@@ -302,6 +311,7 @@ class TrackObject(Signallable, Loggable):
         'priority-changed': ['priority'],
         'selected-changed' : ['state'],
         'stagger-changed' : ['stagger'],
+        'active-changed' : ['active'],
     }
 
     def __init__(self, factory, stream, start=0,
@@ -415,6 +425,8 @@ class TrackObject(Signallable, Loggable):
 
         if self.track is not None:
             self.track.addTrackObject(other)
+            other.gnl_object.set_property("active",
+                                          self.gnl_object.get_property("active"))
 
         interpolators = self.getInterpolators()
         for property, interpolator in interpolators.itervalues():
@@ -451,6 +463,14 @@ class TrackObject(Signallable, Loggable):
 
     start = property(_getStart, setStart)
 
+    def _getActive(self):
+        return self.gnl_object.props.active
+
+    def setActive(self, active):
+        self.gnl_object.props.active = active
+
+    active = property(_getActive, setActive)
+
     def _getDuration(self):
         return self.gnl_object.props.duration
 
@@ -474,6 +494,7 @@ class TrackObject(Signallable, Loggable):
 
     def setInPoint(self, position, snap=False):
         if self.timeline_object is not None:
+
             self.timeline_object.setInPoint(position, snap)
         else:
             self.setObjectInPoint(position)
@@ -522,14 +543,21 @@ class TrackObject(Signallable, Loggable):
         if priority != self._public_priority:
             self._updatePriority(priority)
 
-    def _updatePriority(self, priority):
+    def _getTruePriority (self, priority):
+        """ calculate the priority the contained gnlobject should have """
         if self.stream_type is VideoStream:
-            true_priority = 2 + self._stagger + (3 * priority)
+            return 3 + self._stagger + (3 * priority)
         elif self.stream_type is AudioStream:
-            true_priority  = 2 + (2 * self._stagger) + (4 * priority)
+            return 3 + (2 * self._stagger) + (4 * priority)
+
+    def _updatePriority(self, priority):
+        true_priority = self._getTruePriority(priority)
+
         if self.gnl_object.props.priority != true_priority:
             self.gnl_object.props.priority = true_priority
 
+        self.debug("New priority: %r", self.gnl_object.props.priority)
+
     priority = property(_getPriority, setPriority)
 
     def _getStagger(self):
@@ -566,6 +594,7 @@ class TrackObject(Signallable, Loggable):
     def splitObject(self, position):
         start = self.gnl_object.props.start
         duration = self.gnl_object.props.duration
+        in_point = self.gnl_object.props.media_start
         if position <= start or position >= start + duration:
             raise TrackError("can't split at position %s" % gst.TIME_ARGS(position))
 
@@ -575,10 +604,24 @@ class TrackObject(Signallable, Loggable):
         for prop, i in self.interpolators.itervalues():
             value = i.valueAt(position)
             i.end.setValue(value)
+            keyframes = i.getInteriorKeyframes()
+            duplicates = []
+            for kf in keyframes:
+                if kf.getTime() >= (position - start + in_point):
+                    duplicates.append(kf)
+            for kf in duplicates:
+                i.removeKeyframe(kf)
 
         for prop, i in other.interpolators.itervalues():
             value = i.valueAt(position)
             i.start.setValue(value)
+            keyframes = i.getInteriorKeyframes()
+            duplicates = []
+            for kf in keyframes:
+                if kf.getTime() <= (position - start + in_point):
+                    duplicates.append(kf)
+            for kf in duplicates:
+                i.removeKeyframe(kf)
 
         other.trimObjectStart(position)
         self.setObjectDuration(position - self.gnl_object.props.start)
@@ -649,6 +692,9 @@ class TrackObject(Signallable, Loggable):
             self._public_priority = public_priority
             self.emit('priority-changed', public_priority)
 
+    def _notifyActiveCb(self, obj, pspec):
+        self.emit('active-changed', obj.props.active)
+
     def _connectToSignals(self, gnl_object):
         gnl_object.connect('notify::start', self._notifyStartCb)
         gnl_object.connect('notify::duration', self._notifyDurationCb)
@@ -659,6 +705,8 @@ class TrackObject(Signallable, Loggable):
                 self._notifyMediaStopCb)
         gnl_object.connect('notify::priority',
                 self._notifyPriorityCb)
+        gnl_object.connect('notify::active',
+                self._notifyActiveCb)
 
     def _disconnectFromSignals(self):
         if self.gnl_object:
@@ -684,12 +732,55 @@ class SourceTrackObject(TrackObject):
     numobjs = 0
 
     def _makeGnlObject(self):
-        source = gst.element_factory_make('gnlsource', 
+        source = gst.element_factory_make('gnlsource',
             "gnlsource: " + self.factory.__class__.__name__ +
             str(SourceTrackObject.numobjs))
         SourceTrackObject.numobjs += 1
         return source
 
+class TrackEffect(TrackObject):
+
+    numobjs = 0
+
+    def _makeGnlObject(self):
+        effect = gst.element_factory_make('gnloperation',
+            "gnloperation: " + self.factory.__class__.__name__ +
+            str(TrackEffect.numobjs))
+        TrackEffect.numobjs += 1
+        return effect
+
+    def copy(self):
+        other = TrackObject.copy(self)
+
+        if self.track is not None:
+            element = self.getElement()
+            new_element = other.getElement()
+            for prop in gobject.list_properties(element):
+                value = element.get_property(prop.name)
+                if value != prop.default_value:
+                    new_element.set_property(prop.name, value)
+
+        return other
+
+    def _getTruePriority(self, priority):
+        """
+        The priority of an effect should always be higher than the priority
+        of the track it is applied to. Those priority are affected when we
+        add a TrackObject to timeline
+        """
+        if self.stream_type is VideoStream:
+            return 2 + self._stagger + (3 * priority)
+        elif self.stream_type is AudioStream:
+            return  2 + (2 * self._stagger) + (4 * priority)
+
+    def getElement(self):
+        """
+        Permit to get the gst.Element inside the gnl_object that correspond
+        to the track factory
+        """
+        effect_bin = list(self.gnl_object.elements())[0]
+        return effect_bin.get_by_name("effect")
+
 class Transition(Signallable):
 
     __signals__ = {
@@ -907,11 +998,12 @@ class Track(Signallable, Loggable):
 
         ret.makeBin()
         ret.gnl_object.props.priority = 2 ** 32 - 1
-
+        self.debug("Track Object %r, priority: %r:", ret, ret.gnl_object.props.priority)
         return ret
 
     def _getDefaultVideoTrackObject(self, stream):
         factory = VideoTestSourceFactory(pattern='black')
+        factory.setFilterCaps(stream.caps)
         track_object = SourceTrackObject(factory, stream)
 
         return track_object
@@ -962,6 +1054,10 @@ class Track(Signallable, Loggable):
 
         self.updateDefaultSourcesReal()
 
+    def updateCaps(self, caps):
+        self.stream.caps = caps
+        self.updateDefaultSources()
+
     def updateDefaultSourcesReal(self):
         update = self.composition.props.update
         self.composition.props.update = True
@@ -977,6 +1073,7 @@ class Track(Signallable, Loggable):
             gnl.add(m)
             gnl.props.expandable = True
             gnl.props.priority = 0
+            self.debug("Props priority: %s", gnl.props.priority)
             return gnl
         elif isinstance(stream, VideoStream):
             gnl = gst.element_factory_make("gnloperation", "top-level-video-mixer")
@@ -1164,7 +1261,8 @@ class Track(Signallable, Loggable):
     def getTrackObjectsGroupedByLayer(self):
         layers = [[] for x in xrange(0, self.max_priority + 1)]
         for track_object in self.track_objects:
-            layers[int(track_object.priority)].append(track_object)
+            if not isinstance(track_object, TrackEffect):
+                layers[int(track_object.priority)].append(track_object)
         return layers
 
     def getValidTransitionSlots(self, objs):
@@ -1201,6 +1299,7 @@ class Track(Signallable, Loggable):
                 pop()
                 valid = False
                 safe = end
+
         return slots, valid
 
     valid_arrangement = True
