@@ -40,9 +40,10 @@ from pitivi.stream import VideoStream, AudioStream, TextStream, \
 from pitivi.settings import GlobalSettings
 from pitivi.utils import beautify_length
 from pitivi.ui.common import beautify_factory, factory_name, \
-    beautify_stream
+    beautify_stream, SPACING, PADDING
 from pitivi.log.loggable import Loggable
 from pitivi.sourcelist import SourceListError
+from pitivi.ui.filechooserpreview import PreviewWidget
 
 SHOW_TREEVIEW = 1
 SHOW_ICONVIEW = 2
@@ -72,6 +73,11 @@ GlobalSettings.addConfigOption('lastClipView',
  COL_SEARCH_TEXT,
  COL_SHORT_TEXT) = range(8)
 
+(LOCAL_FILE,
+ LOCAL_DIR,
+ REMOTE_FILE,
+ NOT_A_FILE) = range(4)
+
 ui = '''
 <ui>
     <menubar name="MainMenuBar">
@@ -93,7 +99,7 @@ ui = '''
 </ui>
 '''
 
-INVISIBLE = gtk.gdk.pixbuf_new_from_file(os.path.join(get_pixmap_dir(), 
+INVISIBLE = gtk.gdk.pixbuf_new_from_file(os.path.join(get_pixmap_dir(),
     "invisible.png"))
 
 class SourceList(gtk.VBox, Loggable):
@@ -110,11 +116,12 @@ class SourceList(gtk.VBox, Loggable):
 
         self.app = instance
         self.settings = instance.settings
+        self._errors = []
 
         # Store
         # icon, infotext, objectfactory, uri, length
-        self.storemodel = gtk.ListStore(gtk.gdk.Pixbuf, gtk.gdk.Pixbuf, str, object, str, str,
-            str, str)
+        self.storemodel = gtk.ListStore(gtk.gdk.Pixbuf, gtk.gdk.Pixbuf,
+            str, object, str, str, str, str)
 
         # Scrolled Windows
         self.treeview_scrollwin = gtk.ScrolledWindow()
@@ -150,9 +157,27 @@ class SourceList(gtk.VBox, Loggable):
         # import sources dialogbox
         self._importDialog = None
 
+        # Search/filter box
+        self.search_hbox = gtk.HBox()
+        self.search_hbox.set_spacing(SPACING)
+        self.search_hbox.set_border_width(3)  # Prevents being flush against the notebook
+        searchLabel = gtk.Label(_("Search:"))
+        searchEntry = gtk.Entry()
+        searchEntry.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY, "gtk-clear")
+        searchEntry.connect("changed", self.searchEntryChangedCb)
+        searchEntry.connect("button-press-event", self.searchEntryActivateCb)
+        searchEntry.connect("focus-out-event", self.searchEntryDeactivateCb)
+        searchEntry.connect("icon-press", self.searchEntryIconClickedCb)
+        self.search_hbox.pack_start(searchLabel, expand=False)
+        self.search_hbox.pack_end(searchEntry, expand=True)
+        # Filtering model for the search box.
+        # Use this instead of using self.storemodel directly
+        self.modelFilter = self.storemodel.filter_new()
+        self.modelFilter.set_visible_func(self._setRowVisible, data=searchEntry)
+
         # TreeView
         # Displays icon, name, type, length
-        self.treeview = gtk.TreeView(self.storemodel)
+        self.treeview = gtk.TreeView(self.modelFilter)
         self.treeview_scrollwin.add(self.treeview)
         self.treeview.connect("button-press-event", self._treeViewButtonPressEventCb)
         self.treeview.connect("row-activated", self._rowActivatedCb)
@@ -165,7 +190,7 @@ class SourceList(gtk.VBox, Loggable):
 
         pixbufcol = gtk.TreeViewColumn(_("Icon"))
         pixbufcol.set_expand(False)
-        pixbufcol.set_spacing(5)
+        pixbufcol.set_spacing(SPACING)
         self.treeview.append_column(pixbufcol)
         pixcell = gtk.CellRendererPixbuf()
         pixcell.props.xpad = 6
@@ -175,7 +200,7 @@ class SourceList(gtk.VBox, Loggable):
         namecol = gtk.TreeViewColumn(_("Information"))
         self.treeview.append_column(namecol)
         namecol.set_expand(True)
-        namecol.set_spacing(5)
+        namecol.set_spacing(SPACING)
         namecol.set_sizing(gtk.TREE_VIEW_COLUMN_GROW_ONLY)
         namecol.set_min_width(150)
         txtcell = gtk.CellRendererText()
@@ -192,33 +217,53 @@ class SourceList(gtk.VBox, Loggable):
         namecol.add_attribute(txtcell, "markup", COL_LENGTH)
 
         # IconView
-        self.iconview = gtk.IconView(self.storemodel)
+        self.iconview = gtk.IconView(self.modelFilter)
         self.iconview_scrollwin.add(self.iconview)
         self.iconview.connect("button-press-event", self._iconViewButtonPressEventCb)
         self.iconview.connect("selection-changed", self._viewSelectionChangedCb)
         self.iconview.set_orientation(gtk.ORIENTATION_VERTICAL)
+        self.iconview.set_property("has_tooltip", True)
+        self.iconview.set_tooltip_column(COL_INFOTEXT)
         self.iconview.set_text_column(COL_SHORT_TEXT)
         self.iconview.set_pixbuf_column(COL_ICON_LARGE)
         self.iconview.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.iconview.set_item_width(106)
 
         # Explanatory message InfoBar
-        infobar = gtk.InfoBar()
+        self.infobar = gtk.InfoBar()
 
         txtlabel = gtk.Label()
-        txtlabel.set_padding(10, 10)
+        txtlabel.set_padding(PADDING, PADDING)
         txtlabel.set_line_wrap(True)
         txtlabel.set_line_wrap_mode(pango.WRAP_WORD)
         txtlabel.set_justify(gtk.JUSTIFY_CENTER)
         txtlabel.set_markup(
             _("<span>Import your clips by dragging them here or "
               "by using the buttons above.</span>"))
-        infobar.add(txtlabel)
-        self.infobar = infobar
+        self.infobar.add(txtlabel)
         self.txtlabel = txtlabel
 
-        self.infostub = InfoStub()
-        self.infostub.connect("remove-me", self._removeInfoStub)
+        # The infobar that shows up if there are _errors when importing clips
+        self._import_warning_infobar = gtk.InfoBar()
+        self._import_warning_infobar.set_message_type(gtk.MESSAGE_WARNING)
+        content_area = self._import_warning_infobar.get_content_area()
+        actions_area = self._import_warning_infobar.get_action_area()
+        self._warning_label = gtk.Label()
+        self._warning_label.set_line_wrap(True)
+        self._warning_label.set_line_wrap_mode(pango.WRAP_WORD)
+        self._warning_label.set_justify(gtk.JUSTIFY_CENTER)
+        self._view_error_btn = gtk.Button()
+        self._hide_infobar_btn = gtk.Button()
+        self._hide_infobar_btn.set_label(_("Hide"))
+        self._view_error_btn.connect("clicked", self._viewErrorsButtonClickedCb)
+        self._hide_infobar_btn.connect("clicked",
+                                        self._hideInfoBarClickedCb)
+        content_area.add(self._warning_label)
+        actions_area.add(self._view_error_btn)
+        actions_area.add(self._hide_infobar_btn)
+
+        # The _progressbar that shows up when importing clips
+        self._progressbar = gtk.ProgressBar()
 
         # Connect to project.  We must remove and reset the callbacks when
         # changing project.
@@ -259,9 +304,6 @@ class SourceList(gtk.VBox, Loggable):
         # Hack so that the views have the same method as self
         self.treeview.getSelectedItems = self.getSelectedItems
 
-        # Error dialog box
-        self.errorDialogBox = None
-
         # always available
         actions = (
             ("ImportSources", gtk.STOCK_ADD, _("_Import clips..."),
@@ -271,7 +313,7 @@ class SourceList(gtk.VBox, Loggable):
                 _("Import folder of clips to use"), self._importSourcesFolderCb),
         )
 
-        # only available when selection is non-empty 
+        # only available when selection is non-empty
         selection_actions = (
             ("RemoveSources", gtk.STOCK_DELETE,
                 _("_Remove from project"), "<Control>Delete", None,
@@ -297,9 +339,9 @@ class SourceList(gtk.VBox, Loggable):
         view_menu = view_menu_item.get_submenu()
         seperator = gtk.SeparatorMenuItem()
         self.treeview_menuitem = gtk.RadioMenuItem(None,
-                "Show Clips as a List")
+                _("Show Clips as a List"))
         self.iconview_menuitem = gtk.RadioMenuItem(self.treeview_menuitem,
-                "Show Clips as Icons")
+                _("Show Clips as Icons"))
 
         # update menu items with current clip view before we connect to item
         # signals
@@ -323,8 +365,11 @@ class SourceList(gtk.VBox, Loggable):
 
         # add all child widgets
         self.pack_start(self.infobar, expand=False, fill=False)
+        self.pack_start(self._import_warning_infobar, expand=False, fill=False)
+        self.pack_start(self.search_hbox, expand=False)
         self.pack_start(self.iconview_scrollwin)
         self.pack_start(self.treeview_scrollwin)
+        self.pack_start(self._progressbar, expand=False)
 
         # display the help text
         self.clip_view = self.settings.lastClipView
@@ -352,6 +397,29 @@ class SourceList(gtk.VBox, Loggable):
             start += source.duration
         self.app.action_log.commit()
 
+    def searchEntryChangedCb (self, entry):
+        self.modelFilter.refilter()
+
+    def searchEntryIconClickedCb (self, entry, unused, unsed1):
+        entry.set_text("")
+
+    def searchEntryDeactivateCb(self, entry, event):
+        self.app.gui.setActionsSensitive("default", True)
+
+    def searchEntryActivateCb(self, entry, event):
+        self.app.gui.setActionsSensitive("default", False)
+
+    def _setRowVisible(self, model, iter, data):
+        """
+        Toggle the visibility of a liststore row.
+        Used for the search box.
+        """
+        text = data.get_text().lower()
+        if text == "":
+            return True # Avoid silly warnings
+        else:
+            return text in model.get_value(iter, COL_INFOTEXT).lower()
+
     def _getIcon(self, iconname, alternate):
         icontheme = gtk.icon_theme_get_default()
         pixdir = get_pixmap_dir()
@@ -386,8 +454,7 @@ class SourceList(gtk.VBox, Loggable):
             project.sources, "starting", None, self._sourcesStartedImportingCb)
 
 
-    ## Explanatory message methods
-    
+
     def _setClipView(self, show):
         """ Set which clip view to use when sourcelist is showing clips. If
         none is given, the current one is used. Show: one of SHOW_TREEVIEW or
@@ -456,6 +523,10 @@ class SourceList(gtk.VBox, Loggable):
         self._importDialog.set_default_response(gtk.RESPONSE_OK)
         self._importDialog.set_select_multiple(True)
         self._importDialog.set_modal(False)
+        pw = PreviewWidget(self.app)
+        self._importDialog.set_preview_widget(pw)
+        self._importDialog.set_use_preview_label(False)
+        self._importDialog.connect('update-preview', pw.add_preview_request)
         self._importDialog.set_current_folder(self.app.settings.lastImportFolder)
 
         self._importDialog.connect('response', self._dialogBoxResponseCb, select_folders)
@@ -464,12 +535,31 @@ class SourceList(gtk.VBox, Loggable):
 
     def addUris(self, files):
         """ Add files to the list """
-        self.app.current.sources.addUris(files)
+        try:
+            self.app.current.sources.addUris(files)
+        except SourceListError as error:
+            disclaimer, uri = error.args
+            self.error("'%s' is already present in the source list." + uri)
 
     def addFolders(self, folders):
         """ walks the trees of the folders in the list and adds the files it finds """
         self.app.threads.addThread(PathWalker, folders, self.app.current.sources.addUris)
 
+    def _updateProgressbar(self):
+        """
+        Update the _progressbar with the ratio of clips imported vs the total
+        """
+        current_clip_iter = self.app.current.sources.nb_imported_files
+        total_clips = self.app.current.sources.nb_file_to_import
+        progressbar_text = _("Importing clip %(current_clip)d of %(total)d" %
+            {"current_clip": current_clip_iter,
+            "total": total_clips})
+        self._progressbar.set_text(progressbar_text)
+        if current_clip_iter == 0:
+            self._progressbar.set_fraction(0.0)
+        elif total_clips != 0:
+            self._progressbar.set_fraction((current_clip_iter - 1) / float(total_clips))
+
     def _addFactory(self, factory):
         video = factory.getOutputStreams(VideoStream)
         if video and video[0].thumbnail:
@@ -525,12 +615,13 @@ class SourceList(gtk.VBox, Loggable):
 
     # sourcelist callbacks
 
-    def _sourceAddedCb(self, unused_sourcelist, factory):
+    def _sourceAddedCb(self, sourcelist, factory):
         """ a file was added to the sourcelist """
+        self._updateProgressbar()
         self._addFactory(factory)
         if len(self.storemodel):
             self.infobar.hide_all()
-
+            self.search_hbox.show_all()
 
     def _sourceRemovedCb(self, sourcelist, uri, factory):
         """ the given uri was removed from the sourcelist """
@@ -542,34 +633,42 @@ class SourceList(gtk.VBox, Loggable):
                 break
         if not len(model):
             self._displayHelpText()
+            self.search_hbox.hide()
 
     def _discoveryErrorCb(self, unused_sourcelist, uri, reason, extra):
         """ The given uri isn't a media file """
-        self.infostub.addErrors(uri, reason, extra)
+        error = (uri, reason, extra)
+        self._errors.append(error)
 
     def _missingPluginsCb(self, sourcelist, uri, factory, details, descriptions, cb):
-        self.infostub.addErrors(uri, "Missing plugins", "\n".join(descriptions))
+        error = (uri, "Missing plugins", "\n".join(descriptions))
+        self._errors.append(error)
 
-    def _sourcesStartedImportingCb(self, unused_sourcelist):
-        if not self.infostub.showing:
-            self.pack_start(self.infostub, expand=False)
-        self.infostub.startingImport()
+    def _sourcesStartedImportingCb(self, sourcelist):
+        self._progressbar.show()
+        self._updateProgressbar()
 
     def _sourcesStoppedImportingCb(self, unused_sourcelist):
-        self.infostub.stoppingImport()
+        self._progressbar.hide()
+        if self._errors:
+            if len(self._errors) > 1:
+                self._warning_label.set_text(_("Errors occured while importing."))
+                self._view_error_btn.set_label(_("View errors"))
+            else:
+                self._warning_label.set_text(_("An error occured while importing."))
+                self._view_error_btn.set_label(_("View error"))
 
-    def _removeInfoStub(self, unused_i):
-        self.remove(self.infostub)
+            self._import_warning_infobar.show_all()
 
     ## Error Dialog Box callbacks
 
     def _errorDialogBoxCloseCb(self, unused_dialog):
-        self.errorDialogBox.destroy()
-        self.errorDialogBox = None
+        self._error_dialogbox.destroy()
+        self._error_dialogbox = None
 
     def _errorDialogBoxResponseCb(self, unused_dialog, unused_response):
-        self.errorDialogBox.destroy()
-        self.errorDialogBox = None
+        self._error_dialogbox.destroy()
+        self._error_dialogbox = None
 
     ## Import Sources Dialog Box callbacks
 
@@ -623,7 +722,7 @@ class SourceList(gtk.VBox, Loggable):
         """ Called when a user clicks on the remove button """
         self._removeSources()
 
-    def _playButtonClickedCb(self, unused_widget):
+    def _playButtonClickedCb(self, unused_widget=None):
         """ Called when a user clicks on the play button """
         # get the selected filesourcefactory
         paths = self.getSelectedPaths()
@@ -635,6 +734,29 @@ class SourceList(gtk.VBox, Loggable):
         self.debug("Let's play %s", factory.uri)
         self.emit('play', factory)
 
+    def _hideInfoBarClickedCb(self, unused_button):
+        self._errors = []
+        self._import_warning_infobar.hide()
+
+    def _viewErrorsButtonClickedCb(self, unused_button):
+        """
+        Show a FileListErrorDialog to display import _errors.
+        """
+        if len(self._errors) > 1:
+            msgs = (_("Error while analyzing files"),
+                    _("The following files can not be used with PiTiVi."))
+        else:
+            msgs = (_("Error while analyzing a file"),
+                    _("The following file can not be used with PiTiVi."))
+        self._error_dialogbox = FileListErrorDialog(*msgs)
+        self._error_dialogbox.connect("close", self._errorDialogBoxCloseCb)
+        self._error_dialogbox.connect("response", self._errorDialogBoxResponseCb)
+        for uri, reason, extra in self._errors:
+            self._error_dialogbox.addFailedFile(uri, reason, extra)
+        self._error_dialogbox.show()
+        self._errors = []  # Reset the error list (since the user has read them)
+        self._import_warning_infobar.hide()
+
     def _treeViewMenuItemToggledCb(self, unused_widget):
         if self.treeview_menuitem.get_active():
             show = SHOW_TREEVIEW
@@ -725,7 +847,10 @@ class SourceList(gtk.VBox, Loggable):
     def _treeViewButtonPressEventCb(self, treeview, event):
         chain_up = True
 
-        if event.button == 3:
+        if event.type == gtk.gdk._2BUTTON_PRESS:
+            self._playButtonClickedCb()
+            chain_up = False
+        elif event.button == 3:
             self._viewShowPopup(treeview, event)
             chain_up = False
 
@@ -736,7 +861,7 @@ class SourceList(gtk.VBox, Loggable):
 
             self._dragStarted = False
             self._dragSelection = False
-            self._dragButton = event.button 
+            self._dragButton = event.button
             self._dragX = int(event.x)
             self._dragY = int(event.y)
 
@@ -810,8 +935,10 @@ class SourceList(gtk.VBox, Loggable):
     def _iconViewButtonPressEventCb(self, iconview, event):
         chain_up = True
 
-        #popup menu
-        if event.button == 3:
+        if event.type == gtk.gdk._2BUTTON_PRESS:
+            self._playButtonClickedCb()
+            chain_up = False
+        elif event.button == 3:
             self._viewShowPopup(iconview, event)
             chain_up = False
         else:
@@ -849,11 +976,6 @@ class SourceList(gtk.VBox, Loggable):
         self.storemodel.clear()
         self._connectToProject(project)
 
-    def _newProjectLoadingCb(self, unused_pitivi, uri):
-        if not self.infostub.showing:
-            self.pack_start(self.infostub, expand=False)
-            self.infostub.startingImport()
-
     def _newProjectLoadedCb(self, unused_pitivi, project):
         pass
 
@@ -867,31 +989,46 @@ class SourceList(gtk.VBox, Loggable):
 
     def _dndDataReceivedCb(self, unused_widget, unused_context, unused_x,
                            unused_y, selection, targettype, unused_time):
-        def isfile(path):
+        def get_file_type(path):
             if path[:7] == "file://":
-                # either it's on local system and we know if it's a directory
-                return os.path.isfile(path[7:])
-            elif "://" in path:
-                # or it's not, in which case we assume it's a file
-                return True
-            # or it's on local system with "file://"
-            return os.path.isfile(path)
+                if os.path.isfile(path[7:]):
+                    return LOCAL_FILE
+                return LOCAL_DIR
+            elif "://" in path: #we concider it is a remote file
+                return REMOTE_FILE
+            return NOT_A_FILE
+
 
         self.debug("targettype:%d, selection.data:%r", targettype, selection.data)
         directories = []
         if targettype == dnd.TYPE_URI_LIST:
-            incoming = [unquote(x.strip('\x00')) for x in selection.data.strip().split("\r\n") if x.strip('\x00')]
-            filenames = [x for x in incoming if isfile(x)]
-            directories = [x for x in incoming if not isfile(x)]
+            filenames = []
+            directories = []
+            remote_files = []
+            incoming = [unquote(x.strip('\x00')) for x in selection.data.strip().split("\r\n")
+                        if x.strip('\x00')]
+            for x in incoming:
+                filetype = get_file_type(x)
+                if filetype == LOCAL_FILE:
+                    filenames.append(x)
+                elif filetype == LOCAL_DIR:
+                    directories.append(x)
+                elif filetype == REMOTE_FILE:
+                    remote_files.append(x)
         elif targettype == dnd.TYPE_TEXT_PLAIN:
             incoming = selection.data.strip()
-            if isfile(incoming):
+            file_type = get_file_type(incoming)
+            if file_type == LOCAL_FILE:
                 filenames = [incoming]
-            else:
+            elif file_type == LOCAL_DIR:
                 directories = [incoming]
         if directories:
             self.addFolders(directories)
 
+        if remote_files:
+            #TODO waiting for remote files downloader support to be implemented
+            pass
+
         try:
             self.addUris([quote_uri(uri) for uri in filenames])
         except SourceListError:
@@ -926,7 +1063,7 @@ class SourceList(gtk.VBox, Loggable):
         return paths
 
     def getSelectedItems(self):
-        return [self.storemodel[path][COL_URI] 
+        return [self.storemodel[path][COL_URI]
             for path in self.getSelectedPaths()]
 
     def _dndDataGetCb(self, unused_widget, context, selection,
@@ -938,128 +1075,4 @@ class SourceList(gtk.VBox, Loggable):
         selection.set(selection.target, 8, '\n'.join(uris))
         context.set_icon_pixbuf(INVISIBLE, 0, 0)
 
-class InfoStub(gtk.HBox, Loggable):
-    """
-    Box used to display information on the current state of the lists
-    """
-
-    __gsignals__ = {
-        "remove-me" : (gobject.SIGNAL_RUN_LAST,
-                       gobject.TYPE_NONE,
-                       ( ))
-        }
-
-    def __init__(self):
-        gtk.HBox.__init__(self)
-        Loggable.__init__(self)
-        self.errors = []
-        self.showing = False
-        self._importingmessage = _("Importing clips...")
-        self._errorsmessage = _("Error(s) occurred while importing")
-        self._errormessage = _("An error occurred while importing")
-        self._makeUI()
-
-    def _makeUI(self):
-        self.set_spacing(6)
-        anim = gtk.gdk.PixbufAnimation(get_pixmap_dir() + "/busy.gif")
-        self.busyanim = gtk.image_new_from_animation(anim)
-        self.busyanim.show()
-
-        self.erroricon = gtk.image_new_from_stock(gtk.STOCK_DIALOG_WARNING,
-                                                  gtk.ICON_SIZE_SMALL_TOOLBAR)
-        self.erroricon.show()
-
-        self.infolabel = gtk.Label(self._importingmessage)
-        self.infolabel.set_alignment(0, 0.5)
-        self.infolabel.show()
-
-        self.questionbutton = gtk.Button()
-        self.questionbutton.set_image(gtk.image_new_from_stock(gtk.STOCK_INFO,
-                                                               gtk.ICON_SIZE_SMALL_TOOLBAR))
-        self.questionbutton.connect("clicked", self._questionButtonClickedCb)
-        self.questionbutton.show()
-        self._questionshowing = False
-
-        self.pack_start(self.busyanim, expand=False)
-        self._busyshowing = True
-        self.pack_start(self.infolabel, expand=True, fill=True)
-
-    def startingImport(self):
-        if self.showing:
-            if self.errors:
-                # if we're already showing and we have errors, show spinner
-                self._showBusyAnim()
-        else:
-            self._showBusyAnim()
-            self.infolabel.set_text(self._importingmessage)
-            self._showQuestionButton(False)
-            self.show()
-
-    def stoppingImport(self):
-        if self.errors:
-            self._showErrorIcon()
-            if len(self.errors) > 1:
-                self.infolabel.set_text(self._errorsmessage)
-            else:
-                self.infolabel.set_text(self._errormessage)
-            self._showQuestionButton()
-        else:
-            self.hide()
-            self.emit("remove-me")
-
-    def addErrors(self, *args):
-        self.errors.append(args)
-
-    def _showBusyAnim(self):
-        if self._busyshowing:
-            return
-        self.remove(self.erroricon)
-        self.pack_start(self.busyanim, expand=False)
-        self.reorder_child(self.busyanim, 0)
-        self.busyanim.show()
-        self._busyshowing = True
-
-    def _showErrorIcon(self):
-        if not self._busyshowing:
-            return
-        self.remove(self.busyanim)
-        self.pack_start(self.erroricon, expand=False)
-        self.reorder_child(self.erroricon, 0)
-        self.erroricon.show()
-        self._busyshowing = False
-
-    def _showQuestionButton(self, visible=True):
-        if visible and not self._questionshowing:
-            self.pack_start(self.questionbutton, expand=False)
-            self.questionbutton.show()
-            self._questionshowing = True
-        elif not visible and self._questionshowing:
-            self.remove(self.questionbutton)
-            self._questionshowing = False
-
-    def _errorDialogBoxCloseCb(self, dialog):
-        dialog.destroy()
-
-    def _errorDialogBoxResponseCb(self, dialog, unused_response):
-        dialog.destroy()
-
-    def _questionButtonClickedCb(self, unused_button):
-        if len(self.errors) > 1:
-            msgs = (_("Error while analyzing files"),
-                    _("The following files can not be used with PiTiVi."))
-        else:
-            msgs = (_("Error while analyzing a file"),
-                    _("The following file can not be used with PiTiVi."))
-        # show error dialog
-        dbox = FileListErrorDialog(*msgs)
-        dbox.connect("close", self._errorDialogBoxCloseCb)
-        dbox.connect("response", self._errorDialogBoxResponseCb)
-        for uri, reason, extra in self.errors:
-            dbox.addFailedFile(uri, reason, extra)
-        dbox.show()
-        # reset error list
-        self.errors = []
-        self.hide()
-        self.emit("remove-me")
-
 gobject.type_register(SourceList)
