@@ -35,6 +35,7 @@ from pitivi.ui.common import TRACK_SPACING, unpack_cairo_pattern, \
         LAYER_HEIGHT_EXPANDED, LAYER_SPACING
 from pitivi.ui.controller import Controller
 from pitivi.ui.curve import KW_LABEL_Y_OVERFLOW
+from pitivi.ui.common import SPACING
 
 # cursors to be used for resizing objects
 ARROW = gtk.gdk.Cursor(gtk.gdk.ARROW)
@@ -42,36 +43,37 @@ ARROW = gtk.gdk.Cursor(gtk.gdk.ARROW)
 PLAYHEAD_CURSOR = gtk.gdk.Cursor(gtk.gdk.SB_H_DOUBLE_ARROW)
 
 GlobalSettings.addConfigOption('edgeSnapDeadband',
-    section = "user-interface",
-    key = "edge-snap-deadband",
-    default = 5,
-    notify = True)
+    section="user-interface",
+    key="edge-snap-deadband",
+    default=5,
+    notify=True)
 
 PreferencesDialog.addNumericPreference('edgeSnapDeadband',
-    section = _("Behavior"),
-    label = _("Snap Distance (pixels)"),
-    description = _("Threshold distance (in pixels) used for all snapping "
+    section=_("Behavior"),
+    label=_("Snap Distance (pixels)"),
+    description=_("Threshold distance (in pixels) used for all snapping "
         "operations"),
-    lower = 0)
+    lower=0)
+
 
 class PlayheadController(Controller, Zoomable):
 
     _cursor = PLAYHEAD_CURSOR
 
-
     def __init__(self, *args, **kwargs):
         Controller.__init__(self, *args, **kwargs)
 
     def set_pos(self, item, pos):
-        self._canvas.app.current.seeker.seek(
-            Zoomable.pixelToNs(pos[0]))
+        x, y = pos
+        x += self._hadj.get_value()
+        self._canvas.app.current.seeker.seek(Zoomable.pixelToNs(x))
+
 
 class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
 
     __gtype_name__ = 'TimelineCanvas'
     __gsignals__ = {
-        "scroll-event": "override",
-        "expose-event" : "override",
+        "expose-event": "override",
     }
 
     _tracks = None
@@ -83,7 +85,7 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
         self.app = instance
         self._selected_sources = []
         self._tracks = []
-        self._height = 0
+        self.height = 0
         self._position = 0
 
         self._block_size_request = False
@@ -104,27 +106,31 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
         root.add_child(self.tracks)
         self._marquee = goocanvas.Rect(
             parent=root,
-            stroke_pattern = unpack_cairo_pattern(0x33CCFF66),
-            fill_pattern = unpack_cairo_pattern(0x33CCFF66),
-            visibility = goocanvas.ITEM_INVISIBLE)
+            stroke_pattern=unpack_cairo_pattern(0x33CCFF66),
+            fill_pattern=unpack_cairo_pattern(0x33CCFF66),
+            visibility=goocanvas.ITEM_INVISIBLE)
         self._playhead = goocanvas.Rect(
-            y = -10,
+            y=-10,
             parent=root,
             line_width=1,
             fill_color_rgba=0x000000FF,
             stroke_color_rgba=0xFFFFFFFF,
             width=3)
         self._playhead_controller = PlayheadController(self._playhead)
+        self.connect("size-allocate", self._size_allocate_cb)
         root.connect("motion-notify-event", self._selectionDrag)
         root.connect("button-press-event", self._selectionStart)
         root.connect("button-release-event", self._selectionEnd)
-        height = (LAYER_HEIGHT_EXPANDED + TRACK_SPACING + LAYER_SPACING) * 2
+        self.height = (LAYER_HEIGHT_EXPANDED + TRACK_SPACING +
+                LAYER_SPACING) * 2
         # add some padding for the horizontal scrollbar
-        height += 21
-        self.set_size_request(-1, height)
+        self.height += 21
+        self.set_size_request(-1, self.height)
 
     def from_event(self, event):
-        return Point(*self.convert_from_pixels(event.x, event.y))
+        x, y = event.x, event.y
+        x += self.app.gui.timeline.hadj.get_value()
+        return Point(*self.convert_from_pixels(x, y))
 
     def setExpanded(self, track_object, expanded):
         track_ui = None
@@ -135,30 +141,6 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
 
         track_ui.setExpanded(expanded)
 
-    def do_scroll_event(self, event):
-        if event.state & gtk.gdk.SHIFT_MASK:
-            # shift + scroll => vertical (up/down) scroll
-            if event.direction == gtk.gdk.SCROLL_LEFT:
-                event.direction = gtk.gdk.SCROLL_UP
-            elif event.direction == gtk.gdk.SCROLL_RIGHT:
-                event.direction = gtk.gdk.SCROLL_DOWN
-            event.state &= ~gtk.gdk.SHIFT_MASK
-        elif event.state & gtk.gdk.CONTROL_MASK:
-            # zoom + scroll => zooming (up: zoom in)
-            if event.direction == gtk.gdk.SCROLL_UP:
-                Zoomable.zoomIn()
-                return True
-            elif event.direction == gtk.gdk.SCROLL_DOWN:
-                Zoomable.zoomOut()
-                return True
-            return False
-        else:
-            if event.direction == gtk.gdk.SCROLL_UP:
-                event.direction = gtk.gdk.SCROLL_LEFT
-            elif event.direction == gtk.gdk.SCROLL_DOWN:
-                event.direction = gtk.gdk.SCROLL_RIGHT
-        return goocanvas.Canvas.do_scroll_event(self, event)
-
 ## sets the cursor as appropriate
 
     def _mouseEnterCb(self, unused_item, unused_target, event):
@@ -179,19 +161,6 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
             event.area.x, event.area.y,
             event.area.width, event.area.height)
 
-        y = 0
-        for track in self._tracks[:-1]:
-            y += track.height
-            self.style.paint_box(event.window,
-                gtk.STATE_NORMAL,
-                gtk.SHADOW_OUT,
-                event.area,
-                self,
-                "",
-                event.area.x - 5, y + 1,
-                event.area.width + 10,  TRACK_SPACING - 2)
-            y += TRACK_SPACING 
-
         goocanvas.Canvas.do_expose_event(self, event)
 
 ## implements selection marquee
@@ -201,12 +170,47 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
     _marquee = None
     _got_motion_notify = False
 
-    def _normalize(self, p1, p2):
+    def getItemsInArea(self, x1, y1, x2, y2):
+        '''
+        Permits to get the Non UI L{Track}/L{TrackObject} in a list of set
+        corresponding to the L{Track}/L{TrackObject} which are in the are
+
+        @param x1: The horizontal coordinate of the up left corner of the area
+        @type x1: An C{int}
+        @param y1: The vertical coordinate of the up left corner of the area
+        @type y1: An C{int}
+        @param x2: The horizontal coordinate of the down right corner of the
+                   area
+        @type x2: An C{int}
+        @param x2: The vertical coordinate of the down right corner of the area
+        @type x2: An C{int}
+
+        @returns: A list of L{Track}, L{TrackObject} tuples
+        '''
+        items = self.get_items_in_area(goocanvas.Bounds(x1, y1, x2, y2), True,
+            True, True)
+        if not items:
+            return [], []
+
+        tracks = set()
+        track_objects = set()
+
+        for item in items:
+            if isinstance(item, Track):
+                tracks.add(item.track)
+            elif isinstance(item, TrackObject):
+                track_objects.add(item.element)
+
+        return tracks, track_objects
+
+    def _normalize(self, p1, p2, adjust=0):
         w, h = p2 - p1
         x, y = p1
-        if w < 0:
-            w = abs(w)
+        if w - adjust < 0:
+            w = abs(w - adjust)
             x -= w
+        else:
+            w -= adjust
         if h < 0:
             h = abs(h)
             y -= h
@@ -216,7 +220,8 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
         if self._selecting:
             self._got_motion_notify = True
             cur = self.from_event(event)
-            pos, size = self._normalize(self._mousedown, cur)
+            pos, size = self._normalize(self._mousedown, cur,
+                self.app.gui.timeline.hadj.get_value())
             self._marquee.props.x, self._marquee.props.y = pos
             self._marquee.props.width, self._marquee.props.height = size
             return True
@@ -274,16 +279,17 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
 
     def _request_size(self):
         alloc = self.get_allocation()
-        w = Zoomable.nsToPixel(self.max_duration)
-        h = max(self._height, alloc.height)
-        self.set_bounds(0, 0, w, h)
-        self._playhead.props.height = h + 10
+        self.set_bounds(0, 0, alloc.width, alloc.height)
+        self._playhead.props.height = (self.height + SPACING)
+
+    def _size_allocate_cb(self, widget, allocation):
+        self._request_size()
 
     def zoomChanged(self):
+        self.queue_draw()
         if self.timeline:
             self.timeline.dead_band = self.pixelToNs(
                 self.settings.edgeSnapDeadband)
-            self._request_size()
             self.timelinePositionChanged(self.position)
 
 ## settings callbacks
@@ -329,5 +335,5 @@ class TimelineCanvas(goocanvas.Canvas, Zoomable, Loggable):
         for i, track in enumerate(self._tracks):
             track.set_simple_transform(0, height, 1, 0)
             height += track.height + TRACK_SPACING
-        self._height = height
+        self.height = height
         self._request_size()
