@@ -9,6 +9,7 @@ import os
 import gc
 import unittest
 from pitivi.factories.base import ObjectFactory, SourceFactory, SinkFactory
+from pitivi.factories.operation import EffectFactory
 from pitivi.pipeline import Pipeline
 
 detect_leaks = os.environ.get("PITIVI_TEST_DETECT_LEAKS", "1") not in ("0", "")
@@ -161,3 +162,8 @@ class StubFactory(SourceFactory):
 
     def _releaseBin(self, bin):
         pass
+
+class FakeEffectFactory(EffectFactory):
+    def __init__(self):
+        EffectFactory.__init__(self, 'identity', "identity")
+        self.duration = 42 * gst.SECOND
